@@ -50,6 +50,9 @@ void entrybox(char *title, int width, char *dflt_text, char *comment, int maxch,
 
     GLOBALS->cleanup_entry_c_1=func;
 
+    /* fix problem where ungrab doesn't occur if button pressed + simultaneous accelerator key occurs */
+    if(GLOBALS->in_button_press_wavewindow_c_1) { gdk_pointer_ungrab(GDK_CURRENT_TIME); }
+
     if(GLOBALS->wave_script_args)
 	{
         char *s = NULL;
