@@ -170,6 +170,9 @@ GtkTooltips *tooltips;
 struct Global *old_globals = GLOBALS;
 #endif
 
+/* fix problem where ungrab doesn't occur if button pressed + simultaneous accelerator key occurs */
+if(GLOBALS->in_button_press_wavewindow_c_1) { gdk_pointer_ungrab(GDK_CURRENT_TIME); }
+
 if(!*filesel_path) /* if no name specified, hijack loaded file name path */
 	{
 	if(GLOBALS->loaded_file_name)
