@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Kermin Elliott Fleming 2007-2011.
+ * Copyright (c) Kermin Elliott Fleming 2007-2012.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1508,6 +1508,9 @@ void reload_into_new_context_2(void)
 
  logbox_reload();
 
+ /* fix problem where ungrab doesn't occur if button pressed + simultaneous reload accelerator key occurs */
+ if(GLOBALS->in_button_press_wavewindow_c_1) { gdk_pointer_ungrab(GDK_CURRENT_TIME); }
+
  /* let all GTK/X events spin through in order to keep menus from freezing open during reload */
 #ifndef MAC_INTEGRATION
  if(GLOBALS->text_status_c_2)
@@ -2239,7 +2242,7 @@ void reload_into_new_context_2(void)
  #endif
 
  /* Reload state from file */
- read_save_helper(reload_tmpfilename, NULL, NULL, NULL, NULL); 
+ read_save_helper(reload_tmpfilename, NULL, NULL, NULL, NULL, NULL); 
 
  /* again doing this here (read_save_helper does it) seems to be necessary in order to keep display in sync */
  GLOBALS->signalwindow_width_dirty=1;
@@ -2742,6 +2745,9 @@ if(line)
 
 if(GLOBALS != g)
 	{
+	/* fix problem where ungrab doesn't occur if button pressed + simultaneous context swap occurs */
+ 	if(GLOBALS && GLOBALS->in_button_press_wavewindow_c_1) { gdk_pointer_ungrab(GDK_CURRENT_TIME); }
+
 	GLOBALS = g;
 	sprintf(sstr, "%d", GLOBALS->this_context_page);
 	gtkwavetcl_setvar(WAVE_TCLCB_CURRENT_ACTIVE_TAB, sstr, WAVE_TCLCB_CURRENT_ACTIVE_TAB_FLAGS);
