@@ -566,9 +566,8 @@ for(yytext[len++]=ch;;yytext[len++]=ch)
         ch=getch();  
         if(ch==' ')
                 {
-                signed char ch2;
                 if(match_kw) break;
-                if((ch2 = getch_peek()) == '[')
+                if(getch_peek() == '[')
                         {
                         ch = getch();
                         varsplit=yytext+len; /* keep looping so we get the *last* one */
@@ -659,14 +658,14 @@ static void sync_end(char *hdr)
 {
 int tok;
 
-if(hdr) DEBUG(fprintf(stderr,"%s",hdr));
+if(hdr) { DEBUG(fprintf(stderr,"%s",hdr)); }
 for(;;)
 	{
 	tok=get_token();
 	if((tok==T_END)||(tok==T_EOF)) break;
-	if(hdr)DEBUG(fprintf(stderr," %s",yytext));
+	if(hdr) { DEBUG(fprintf(stderr," %s",yytext)); }
 	}
-if(hdr) DEBUG(fprintf(stderr,"\n"));
+if(hdr) { DEBUG(fprintf(stderr,"\n")); }
 }
 
 static char *build_slisthier(void)
@@ -1015,7 +1014,7 @@ int tok;
 
 for(;;)
 	{
-	switch(tok=get_token())
+	switch(get_token())
 		{
 		case T_COMMENT:
 			sync_end("COMMENT:");
@@ -1471,7 +1470,7 @@ if(!n->curr)
 	}
 	else
 	{
-	if(regadd) { t_time*=(time_scale); }
+	/* if(regadd) { t_time*=(time_scale); } */ /* scan-build : never read */
 
 	if(toupper((int)(unsigned char)ch)!=deadchar) n->notdead=1;
 	n->numtrans++;
@@ -1870,7 +1869,7 @@ printf(
 "VCD files may be compressed with zip or gzip.  Note that VCDFILE and VZTFILE\n"
 "are optional provided the --vcdname and --vztname options are specified.\n"
 "Use \"-\" as a VCD filename to accept uncompressed input from stdin.\n\n"
-"Report bugs to <bybell@nc.rr.com>.\n",nam);
+"Report bugs to <"PACKAGE_BUGREPORT">.\n",nam);
 #else
 printf(
 "Usage: %s [OPTION]... [VCDFILE] [VZTFILE]\n\n"
@@ -1887,7 +1886,7 @@ printf(
 "VCD files may be compressed with zip or gzip.  Note that VCDFILE and VZTFILE\n"
 "are optional provided the --vcdname and --vztname options are specified.\n"
 "Use \"-\" as a VCD filename to accept uncompressed input from stdin.\n\n"
-"Report bugs to <bybell@nc.rr.com>.\n",nam);
+"Report bugs to <"PACKAGE_BUGREPORT">.\n",nam);
 #endif
 
 exit(0);
