@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2009 Tony Bybell.
+ * Copyright (c) 2003-2011 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -44,6 +44,20 @@
 
 /****************************************************************************/
 
+static int is_big_endian(void)
+{
+union 	
+	{ 
+	vztint32_t u32; 
+	unsigned char c[sizeof(vztint32_t)];
+	} u;
+
+u.u32 = 1;
+return(u.c[sizeof(vztint32_t)-1] == 1);
+}
+
+/****************************************************************************/
+
 struct vzt_ncycle_autosort
 {
 struct vzt_ncycle_autosort *next;
@@ -346,7 +360,6 @@ vztint32_t *val_dict=NULL;
 int num_time_ticks, num_sections, num_dict_entries;
 char *pnt = b->mem;
 int i, j, m, num_dict_words;
-const char endian_word[] = { 0x01, 0x02, 0x03, 0x04 };
 /* vztint32_t *block_end = (vztint32_t *)(pnt + b->uncompressed_siz); */
 vztint32_t *val_tmp;
 unsigned int num_bitplanes;
@@ -441,7 +454,7 @@ b->multi_state = (num_bitplanes > 1);
 padskip = ((long)pnt)&3; pnt += (padskip) ? 4-padskip : 0; /* skip pad to next 4 byte boundary */
 b->vindex = (vztint32_t *)(pnt);
 
-if(*((int *)((void *)endian_word)) == 0x01020304) /* have to bswap the value changes on big endian machines... */
+if(is_big_endian()) /* have to bswap the value changes on big endian machines... */
 	{
 	if(!b->rle)
 		{
@@ -475,7 +488,9 @@ if(b->num_str_entries)
 		}
 	}
 
-change_dict = malloc((num_dict_words = num_sections * num_dict_entries) * sizeof(vztint32_t));
+
+num_dict_words = (num_sections * num_dict_entries) * sizeof(vztint32_t);
+change_dict = malloc(num_dict_words ? num_dict_words : sizeof(vztint32_t)); /* scan-build */
 m = 0;
 for(i=0;i<num_dict_entries;i++)
 	{
@@ -708,7 +723,7 @@ XDR x;
 const vztint32_t endian_matchword = 0x12345678;
 #endif
 double d;
-char xdrdata[8];
+char xdrdata[8] = { 0,0,0,0,0,0,0,0 }; /* scan-build */
 
 for(j=0;j<64;j++)
 	{
@@ -1029,7 +1044,7 @@ if((lt)&&(facidx<lt->numfacs))
 }
 
 
-_VZT_RD_INLINE vztint32_t vzt_rd_get_fac_msb(struct vzt_rd_trace *lt, vztint32_t facidx)
+_VZT_RD_INLINE vztsint32_t vzt_rd_get_fac_msb(struct vzt_rd_trace *lt, vztint32_t facidx)
 {
 if((lt)&&(facidx<lt->numfacs))
 	{
@@ -1042,7 +1057,7 @@ if((lt)&&(facidx<lt->numfacs))
 }
 
 
-_VZT_RD_INLINE vztint32_t vzt_rd_get_fac_lsb(struct vzt_rd_trace *lt, vztint32_t facidx)
+_VZT_RD_INLINE vztsint32_t vzt_rd_get_fac_lsb(struct vzt_rd_trace *lt, vztint32_t facidx)
 {
 if((lt)&&(facidx<lt->numfacs))
 	{
@@ -1849,8 +1864,8 @@ if(!(lt->handle=fopen(name, "rb")))
 		pos = pos+lt->zfacgeometrysize;
 
 		lt->rows = malloc(lt->numfacs * sizeof(vztint32_t));
-		lt->msb = malloc(lt->numfacs * sizeof(vztint32_t));
-		lt->lsb = malloc(lt->numfacs * sizeof(vztint32_t));
+		lt->msb = malloc(lt->numfacs * sizeof(vztsint32_t));
+		lt->lsb = malloc(lt->numfacs * sizeof(vztsint32_t));
 		lt->flags = malloc(lt->numfacs * sizeof(vztint32_t));
 		lt->len = malloc(lt->numfacs * sizeof(vztint32_t));
 		lt->vindex_offset = malloc(lt->numfacs * sizeof(vztint32_t));
@@ -1999,7 +2014,7 @@ return(lt);
  */
 void vzt_rd_vectorize(struct vzt_rd_trace *lt)
 {
-if((!lt)||(lt->vectorize))
+if((!lt)||(lt->vectorize)||(lt->numfacs<2))
 	{
 	return;
 	}
@@ -2140,8 +2155,11 @@ if((!lt)||(lt->vectorize))
 						else
 						{
 						synvec_chain[j] = malloc(sizeof(struct vzt_synvec_chain));
-						synvec_chain[j]->num_entries = 1;
-						synvec_chain[j]->chain[0] = i;
+						if(synvec_chain[j]) /* scan-build : deref of null pointer below */
+							{
+							synvec_chain[j]->num_entries = 1;
+							synvec_chain[j]->chain[0] = i;
+							}
 
 						lt->flags[i] |= VZT_RD_SYM_F_SYNVEC;
 						lt->flags[i] &= ~VZT_RD_SYM_F_ALIAS;
