@@ -1538,10 +1538,11 @@ pr_draw_hptr_trace (pr_context * prc, Trptr t, hptr h, int which, int dodraw,
  */
 static void
 pr_draw_hptr_trace_vector_analog (pr_context * prc, Trptr t, hptr h,
-				  int which, int num_extension)
+				  int which, int num_extension_clip, int num_extension)
 {
   TimeType _x0, _x1, newtime;
   int _y0, _y1, yu, liney, /* ytext, */ yt0, yt1; /* scan-build */
+  int _y0c;
   TimeType tim, h2tim;
   hptr h2, h3;
   int endcnt = 0;
@@ -1553,10 +1554,12 @@ pr_draw_hptr_trace_vector_analog (pr_context * prc, Trptr t, hptr h,
   int is_nan = 0, is_nan2 = 0, is_inf = 0, is_inf2 = 0;
   int any_infs = 0, any_infp = 0, any_infm = 0;
   int skipcnt = 0;
+  int line_in_range;
 
   liney = ((which + 2 + num_extension) * GLOBALS->fontheight) - 2;
   _y1 = ((which + 1) * GLOBALS->fontheight) + 2;
   _y0 = liney - 2;
+  _y0c = (((which + 2 + num_extension_clip) * GLOBALS->fontheight) - 2) - 2;
   yu = (_y0 + _y1) / 2;
   /* ytext = yu - (GLOBALS->wavefont->ascent / 2) + GLOBALS->wavefont->ascent; */ /* scan-build */
 
@@ -1568,7 +1571,7 @@ pr_draw_hptr_trace_vector_analog (pr_context * prc, Trptr t, hptr h,
 
   if (t->flags & TR_ANALOG_FULLSCALE)	/* otherwise use dynamic */
     {
-      if (!t->minmax_valid)
+      if((!t->minmax_valid)||(t->d_num_ext != num_extension))
 	{
 	  h3 = &t->n.nd->head;
 	  for (;;)
@@ -1644,6 +1647,7 @@ pr_draw_hptr_trace_vector_analog (pr_context * prc, Trptr t, hptr h,
 	  t->minmax_valid = 1;
 	  t->d_minval = tmin;
 	  t->d_maxval = tmax;
+          t->d_num_ext = num_extension;
 	}
       else
 	{
@@ -1892,14 +1896,16 @@ coords[3] = yt1;
 rect[0] = -10;   
 rect[1] = _y1;
 rect[2] = GLOBALS->wavewidth + 10;
-rect[3] = _y0;          
+rect[3] = _y0c;          
                                 
 if((t->flags & (TR_ANALOG_INTERPOLATED|TR_ANALOG_STEP)) != TR_ANALOG_STEP)
         {
-        wave_lineclip(coords, rect);
+        line_in_range = wave_lineclip(coords, rect);
         }
         else
         {
+	line_in_range = 1;
+
         if(coords[0] < rect[0]) coords[0] = rect[0];
         if(coords[2] < rect[0]) coords[2] = rect[0];
 
@@ -1922,6 +1928,8 @@ yt1 = coords[3];
 
 	  if (is_nan || is_nan2)
 	    {
+	    if(line_in_range)
+	      {
 	      if (is_nan)
 		{
 		  pr_setgray (prc, 0.70);
@@ -1961,18 +1969,24 @@ yt1 = coords[3];
 		      pr_draw_line (prc, _x1, _y1 - 1, _x1, _y1 + 1);
 		    }
 		}
+              }
 	    }
 	  else if (t->flags & TR_ANALOG_INTERPOLATED && !is_inf && !is_inf2)
 	    {
+	    if(line_in_range)
+              {
 	      pr_draw_line (prc, _x0, yt0, _x1, yt1);
 	      if (t->flags & TR_ANALOG_STEP)
 		{
 		  pr_draw_line (prc, _x0 - 1, yt0, _x0 + 1, yt0);
 		  pr_draw_line (prc, _x0, yt0 - 1, _x0, yt0 + 1);
 		}
+              }
 	    }
 	  else			/* if (t->flags & TR_ANALOG_STEP) */
 	    {
+            if(line_in_range)
+              {
 	      pr_draw_line (prc, _x0, yt0, _x1, yt0);
 	      pr_draw_line (prc, _x1, yt0, _x1, yt1);
 
@@ -1982,6 +1996,7 @@ yt1 = coords[3];
 		  pr_draw_line (prc, _x0 - 1, yt0, _x0 + 1, yt0);
 		  pr_draw_line (prc, _x0, yt0 - 1, _x0, yt0 + 1);
 		}
+              }
 	    }
 	}
       else
@@ -2054,6 +2069,7 @@ pr_draw_hptr_trace_vector (pr_context * prc, Trptr t, hptr h, int which)
     {
       Trptr te = GiveNextTrace(t);
       int ext = 0;
+      int ext_total;
       int num_traces_displayable =
 	GLOBALS->signalarea->allocation.height / GLOBALS->fontheight;
 
@@ -2070,6 +2086,7 @@ pr_draw_hptr_trace_vector (pr_context * prc, Trptr t, hptr h, int which)
 	    }
 	}
 
+      ext_total = ext;
       if (which + ext > num_traces_displayable - 2)
 	{
 	  ext = num_traces_displayable - which - 2;
@@ -2077,7 +2094,7 @@ pr_draw_hptr_trace_vector (pr_context * prc, Trptr t, hptr h, int which)
 	    ext = 0;		/* just in case of a one-off */
 	}
 
-      pr_draw_hptr_trace_vector_analog (prc, t, h, which, ext);
+      pr_draw_hptr_trace_vector_analog (prc, t, h, which, ext, ext_total);
       GLOBALS->tims.start -= GLOBALS->shift_timebase;
       GLOBALS->tims.end -= GLOBALS->shift_timebase;
       return;
@@ -2279,10 +2296,11 @@ pr_draw_hptr_trace_vector (pr_context * prc, Trptr t, hptr h, int which)
  */
 static void
 pr_draw_vptr_trace_analog (pr_context * prc, Trptr t, vptr v, int which,
-			   int num_extension)
+			   int num_extension_clip, int num_extension)
 {
   TimeType _x0, _x1, newtime;
   int _y0, _y1, yu, liney, /* ytext, */ yt0, yt1; /* scan-build */
+  int _y0c;
   TimeType tim, h2tim;
   vptr h, h2, h3;
   int endcnt = 0;
@@ -2293,11 +2311,14 @@ pr_draw_vptr_trace_analog (pr_context * prc, Trptr t, vptr v, int which,
   double tmin = mynan, tmax = mynan, tv, tv2;
   int is_nan = 0, is_nan2 = 0, is_inf = 0, is_inf2 = 0;
   int any_infs = 0, any_infp = 0, any_infm = 0;
+  int skipcnt = 0;
+  int line_in_range;
 
   h = v;
   liney = ((which + 2 + num_extension) * GLOBALS->fontheight) - 2;
   _y1 = ((which + 1) * GLOBALS->fontheight) + 2;
   _y0 = liney - 2;
+  _y0c = (((which + 2 + num_extension_clip) * GLOBALS->fontheight) - 2) - 2;
   yu = (_y0 + _y1) / 2;
 
   /* ytext = yu - (GLOBALS->wavefont->ascent / 2) + GLOBALS->wavefont->ascent; */ /* scan-build */
@@ -2310,7 +2331,7 @@ pr_draw_vptr_trace_analog (pr_context * prc, Trptr t, vptr v, int which,
 
   if (t->flags & TR_ANALOG_FULLSCALE)	/* otherwise use dynamic */
     {
-      if (!t->minmax_valid)
+      if((!t->minmax_valid)||(t->d_num_ext != num_extension))
 	{
 	  h3 = t->n.vec->vectors[0];
 	  for (;;)
@@ -2375,6 +2396,7 @@ pr_draw_vptr_trace_analog (pr_context * prc, Trptr t, vptr v, int which,
 	  t->minmax_valid = 1;
 	  t->d_minval = tmin;
 	  t->d_maxval = tmax;
+          t->d_num_ext = num_extension;
 	}
       else
 	{
@@ -2531,8 +2553,17 @@ pr_draw_vptr_trace_analog (pr_context * prc, Trptr t, vptr v, int which,
 	  yt1 = _y0 + (tv2 - tmin) * tmax;
 	}
 
-      if (_x0 != _x1)
+      if((_x0!=_x1)||(skipcnt < GLOBALS->analog_redraw_skip_count)) /* lower number = better performance */
 	{
+          if(_x0==_x1)
+                {
+                skipcnt++; 
+                }
+                else
+                {
+                skipcnt = 0;
+                }
+
 	  if (h->next)
 	    {
 	      if (h->next->time > GLOBALS->max_time)
@@ -2544,8 +2575,68 @@ pr_draw_vptr_trace_analog (pr_context * prc, Trptr t, vptr v, int which,
 	  if ((is_nan2) && (h2tim > GLOBALS->max_time))
 	    is_nan2 = 0;
 
+/* clamp to top/bottom because of integer rounding errors */
+
+if(yt0 < _y1) yt0 = _y1;
+else if(yt0 > _y0) yt0 = _y0;
+                        
+if(yt1 < _y1) yt1 = _y1;
+else if(yt1 > _y0) yt1 = _y0;
+
+/* clipping... */
+{
+int coords[4];
+int rect[4];
+
+if(_x0 < INT_MIN) { coords[0] = INT_MIN; }
+else if(_x0 > INT_MAX) { coords[0] = INT_MAX; }
+else { coords[0] = _x0; }
+
+if(_x1 < INT_MIN) { coords[2] = INT_MIN; }
+else if(_x1 > INT_MAX) { coords[2] = INT_MAX; }
+else { coords[2] = _x1; }
+
+coords[1] = yt0;
+coords[3] = yt1;
+
+                                
+rect[0] = -10;   
+rect[1] = _y1;
+rect[2] = GLOBALS->wavewidth + 10;
+rect[3] = _y0c;          
+                                
+if((t->flags & (TR_ANALOG_INTERPOLATED|TR_ANALOG_STEP)) != TR_ANALOG_STEP)
+        {
+        line_in_range = wave_lineclip(coords, rect);
+        }
+        else
+        {
+	line_in_range = 1;
+
+        if(coords[0] < rect[0]) coords[0] = rect[0];
+        if(coords[2] < rect[0]) coords[2] = rect[0];
+
+        if(coords[0] > rect[2]) coords[0] = rect[2];
+        if(coords[2] > rect[2]) coords[2] = rect[2];
+
+        if(coords[1] < rect[1]) coords[1] = rect[1];
+        if(coords[3] < rect[1]) coords[3] = rect[1];
+
+        if(coords[1] > rect[3]) coords[1] = rect[3];
+        if(coords[3] > rect[3]) coords[3] = rect[3];
+        }
+
+_x0 = coords[0];
+yt0 = coords[1];
+_x1 = coords[2];
+yt1 = coords[3];
+}
+/* ...clipping */
+
 	  if (is_nan || is_nan2)
 	    {
+	    if(line_in_range)
+	      {
 	      if (is_nan)
 		{
 		  pr_setgray (prc, 0.70);
@@ -2585,18 +2676,24 @@ pr_draw_vptr_trace_analog (pr_context * prc, Trptr t, vptr v, int which,
 		      pr_draw_line (prc, _x1, _y1 - 1, _x1, _y1 + 1);
 		    }
 		}
+              }
 	    }
 	  else if ((t->flags & TR_ANALOG_INTERPOLATED) && !is_inf && !is_inf2)
 	    {
+	    if(line_in_range)
+	      {
 	      pr_draw_line (prc, _x0, yt0, _x1, yt1);
 	      if (t->flags & TR_ANALOG_STEP)
 		{
 		  pr_draw_line (prc, _x0 - 1, yt0, _x0 + 1, yt0);
 		  pr_draw_line (prc, _x0, yt0 - 1, _x0, yt0 + 1);
 		}
+              }
 	    }
 	  else			/* if (t->flags & TR_ANALOG_STEP) */
 	    {
+	    if(line_in_range)
+	      {
 	      pr_draw_line (prc, _x0, yt0, _x1, yt0);
 	      pr_draw_line (prc, _x1, yt0, _x1, yt1);
 
@@ -2606,6 +2703,7 @@ pr_draw_vptr_trace_analog (pr_context * prc, Trptr t, vptr v, int which,
 		  pr_draw_line (prc, _x0 - 1, yt0, _x0 + 1, yt0);
 		  pr_draw_line (prc, _x0, yt0 - 1, _x0, yt0 + 1);
 		}
+              }
 	    }
 	}
       else
@@ -2681,6 +2779,9 @@ pr_draw_vptr_trace (pr_context * prc, Trptr t, vptr v, int which)
     {
       Trptr te = GiveNextTrace(t);
       int ext = 0;
+      int ext_total;
+      int num_traces_displayable =
+	GLOBALS->signalarea->allocation.height / GLOBALS->fontheight;
 
       while (te)
 	{
@@ -2695,7 +2796,15 @@ pr_draw_vptr_trace (pr_context * prc, Trptr t, vptr v, int which)
 	    }
 	}
 
-      pr_draw_vptr_trace_analog (prc, t, v, which, ext);
+      ext_total = ext;
+      if (which + ext > num_traces_displayable - 2)
+	{
+	  ext = num_traces_displayable - which - 2;
+	  if (ext < 0)
+	    ext = 0;		/* just in case of a one-off */
+	}
+
+      pr_draw_vptr_trace_analog (prc, t, v, which, ext, ext_total);
 
       GLOBALS->tims.start+=GLOBALS->shift_timebase;
       GLOBALS->tims.end+=GLOBALS->shift_timebase;
