@@ -221,6 +221,9 @@ void renderbox(char *title)
     GtkWidget *button1, *button2;
     int i;
 
+    /* fix problem where ungrab doesn't occur if button pressed + simultaneous accelerator key occurs */
+    if(GLOBALS->in_button_press_wavewindow_c_1) { gdk_pointer_ungrab(GDK_CURRENT_TIME); }
+
     if(GLOBALS->wave_script_args)
         {
         char *s1 = NULL;
