@@ -659,6 +659,9 @@ static void entrybox_local(char *title, int width, char *default_text, int maxch
 
     GLOBALS->cleanup_e_treesearch_gtk2_c_3=func;
 
+    /* fix problem where ungrab doesn't occur if button pressed + simultaneous accelerator key occurs */
+    if(GLOBALS->in_button_press_wavewindow_c_1) { gdk_pointer_ungrab(GDK_CURRENT_TIME); }
+
     /* create a new modal window */
     GLOBALS->window1_treesearch_gtk2_c_3 = gtk_window_new(GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
     install_focus_cb(GLOBALS->window1_treesearch_gtk2_c_3, ((char *)&GLOBALS->window1_treesearch_gtk2_c_3) - ((char *)GLOBALS));
@@ -1211,6 +1214,9 @@ void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window)
     GtkTooltips *tooltips;
     GtkCList  *clist;
 
+    /* fix problem where ungrab doesn't occur if button pressed + simultaneous accelerator key occurs */
+    if(GLOBALS->in_button_press_wavewindow_c_1) { gdk_pointer_ungrab(GDK_CURRENT_TIME); }
+
     if(old_window)
 	{
 	GLOBALS->is_active_treesearch_gtk2_c_6=1;
