@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2011.
+ * Copyright (c) Tony Bybell 1999-2012.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -2656,7 +2656,6 @@ if(GLOBALS->yytext_vcd_recoder_c_3)
 
 TimeType vcd_recoder_main(char *fname)
 {
-int flen;
 unsigned int finalize_cnt = 0;
 struct stat mystat;
 int stat_rc = stat(fname, &mystat);
@@ -2699,9 +2698,7 @@ if(!GLOBALS->hier_was_explicitly_set) /* set default hierarchy split char */
 	GLOBALS->hier_delimeter='.';
 	}
 
-flen=strlen(fname);
-if (((flen>2)&&(!strcmp(fname+flen-3,".gz")))||
-   ((flen>3)&&(!strcmp(fname+flen-4,".zip"))))
+if(suffix_check(fname, ".gz") || suffix_check(fname, ".zip"))
 	{
 	char *str;
 	int dlen;
@@ -2869,6 +2866,7 @@ if(GLOBALS->blackout_regions)
 /* is_vcd=~0; */
 GLOBALS->is_lx2 = LXT2_IS_VLIST;
 
+/* SPLASH */                            splash_finalize();
 return(GLOBALS->max_time);
 }
 
